package com.hms_networks.americas.sc.ignition.comm;

/**
 * Class containing shared/common variables (constants) for the {@link
 * com.hms_networks.americas.sc.ignition.comm} package.
 *
 * @author HMS Networks, MU Americas Solution Center
 * @since 2.0.0
 * @version 1.0.0
 */
public class CommunicationConstants {

  /**
   * The parameter key for the Talk2M account name field in the body of a request to a Talk2M API.
   *
   * @since 1.0.0
   */
  public static final String T2M_ACCOUNT_KEY = "t2maccount";

  /**
   * The parameter key for the Talk2M account username field in the body of a request to a Talk2M
   * API.
   *
   * @since 1.0.0
   */
  public static final String T2M_USERNAME_KEY = "t2musername";

  /**
   * The parameter key for the Talk2M account password field in the body of a request to a Talk2M
   * API.
   *
   * @since 1.0.0
   */
  public static final String T2M_PASSWORD_KEY = "t2mpassword";

  /**
   * The parameter key for the Talk2M session ID field in the body of a request to a Talk2M API.
   *
   * @since 1.0.0
   */
  public static final String T2M_SESSION_ID_KEY = "t2msession";

  /**
   * The parameter key for the Talk2M token field in the body of a request to a Talk2M API.
   *
   * @since 1.0.0
   */
  public static final String T2M_TOKEN_KEY = "t2mtoken";

  /**
   * The parameter key for the Talk2M developer ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_DEVELOPER_ID_KEY = "t2mdevid";

  /**
   * The parameter key for the Ewon ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_EWONID_KEY = "ewonId";

  /**
   * The parameter key for the Tag ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_TAGID_KEY = "tagId";

  /**
   * The parameter key for the Transaction ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_TRANSACTIONID_KEY = "transactionId";

  /**
   * The parameter key for the From field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_FROM_KEY = "from";

  /**
   * The parameter key for the To field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_TO_KEY = "to";

  /**
   * The parameter key for the ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_ID_KEY = "id";

  /**
   * The parameter key for the Name field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_NAME_KEY = "name";

  /**
   * The parameter key for the fullConfig field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_FULL_CONFIG_KEY = "fullConfig";

  /**
   * The parameter value for the fullConfig field in the body of a request to the DMWeb API. This is
   * null, because the fullConfig parameter does not require a value.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_FULL_CONFIG_VALUE = null;

  /**
   * The parameter key for the Limit field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_LIMIT_KEY = "limit";

  /**
   * The parameter key for the Create Transaction field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_CREATE_TRANSACTION_KEY = "createTransaction";

  /**
   * The parameter key for the Last Transaction ID field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_LAST_TID_KEY = "lastTransactionId";

  /**
   * The parameter key for the Ewon IDs field in the body of a request to the DMWeb API.
   *
   * @since 1.0.0
   */
  public static final String T2M_DMW_PARAM_EWON_IDS_KEY = "ewonIds";

  /**
   * The parameter key for the Talk2M device username field in the body of a request to a Talk2M
   * API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_DEVICE_USERNAME_KEY = "t2mdeviceusername";

  /**
   * The parameter key for the Talk2M device password field in the body of a request to a Talk2M
   * API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_DEVICE_PASSWORD_KEY = "t2mdevicepassword";

  /**
   * The parameter key for the Talk2M developer ID field in the body of a request to the M2Web API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_DEVELOPER_ID_KEY = "t2mdeveloperid";

  /**
   * The parameter key for the Pool field in the body of a request to the M2Web API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_POOL_KEY = "pool";

  /**
   * The parameter key for the Ewon field in the body of a request to the M2Web API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_EWON_KEY = "ewon";

  /**
   * The parameter key for the Ewon name field in the body of a request to the M2Web API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_EWON_NAME_KEY = "name";

  /**
   * The parameter key for the Ewon ID field in the body of a request to the M2Web API.
   *
   * @since 1.0.0
   */
  public static final String T2M_M2W_EWON_ID_KEY = "id";
}
